@@ -166,6 +166,12 @@ AndroidMediaLibrary::forceParserRetry()
     p_ml->forceParserRetry();
 }
 
+void
+AndroidMediaLibrary::forceRescan()
+{
+    p_ml->forceRescan();
+}
+
 bool
 AndroidMediaLibrary::increasePlayCount(int64_t mediaId)
 {
@@ -287,9 +293,9 @@ AndroidMediaLibrary::album(int64_t albumId)
 }
 
 std::vector<medialibrary::ArtistPtr>
-AndroidMediaLibrary::artists()
+AndroidMediaLibrary::artists(bool includeAll)
 {
-    return p_ml->artists();
+    return p_ml->artists(includeAll);
 }
 
 medialibrary::ArtistPtr
@@ -339,7 +345,7 @@ std::vector<medialibrary::MediaPtr>
 AndroidMediaLibrary::mediaFromArtist( int64_t artistId )
 {
     auto artist = p_ml->artist(artistId);
-    return artist == nullptr ? std::vector<medialibrary::MediaPtr>() : artist->media();
+    return artist == nullptr ? std::vector<medialibrary::MediaPtr>() : artist->media(medialibrary::SortingCriteria::Album);
 }
 
 std::vector<medialibrary::AlbumPtr>
@@ -353,7 +359,7 @@ std::vector<medialibrary::MediaPtr>
 AndroidMediaLibrary::mediaFromGenre( int64_t genreId )
 {
     auto genre = p_ml->genre(genreId);
-    return genre == nullptr ? std::vector<medialibrary::MediaPtr>() : genre->tracks();
+    return genre == nullptr ? std::vector<medialibrary::MediaPtr>() : genre->tracks(medialibrary::SortingCriteria::Album);
 }
 
 std::vector<medialibrary::AlbumPtr>
