@@ -4,9 +4,9 @@ import android.support.annotation.NonNull;
 import android.support.v7.widget.RecyclerView;
 
 import org.jetbrains.annotations.NotNull;
+import org.videolan.medialibrary.Medialibrary;
 import org.videolan.medialibrary.media.MediaLibraryItem;
 import org.videolan.vlc.gui.DiffUtilAdapter;
-import org.videolan.vlc.util.MediaItemDiffCallback;
 import org.videolan.vlc.util.MediaLibraryItemComparator;
 import org.videolan.vlc.util.Util;
 
@@ -38,8 +38,8 @@ public abstract class SortableAdapter<T extends MediaLibraryItem, VH extends Rec
     }
 
     public void updateIfSortChanged() {
-        if (!hasPendingUpdates() && hasSortChanged())
-            update(new ArrayList<>(getDataset()));
+        final Medialibrary ml = VLCApplication.getMLInstance();
+        if (ml.isInitiated() && !ml.isWorking() && !hasPendingUpdates() && hasSortChanged()) update(new ArrayList<>(peekLast()));
     }
 
     private boolean hasSortChanged() {
